@@ -156,23 +156,27 @@ callback_pipe_read(void * cookie, int status)
 	/* Success! */
 	return (0);
 
-fail:
-	/* Record that this connection is broken. */
-	*(P->status) = -1;
-
-	/* Inform the upstream that our status has changed. */
-	return ((P->callback)(P->cookie));
-
 eof:
 	/* We aren't going to write any more. */
 	if (shutdown(P->s_out, SHUT_WR)) {
-		/*
-		 * We've already received an EOF, so it's no cause for concern
-		 * if the other side has already closed the connection.
-		 */
-		if (errno != ENOTCONN) {
-			warnp("shutdown");
+		switch (errno) {
+		case EBADF:
+		case EINVAL:
+		case ENOTSOCK:
+			/* Should never happen. */
 			goto err0;
+		case ENOTCONN:
+		case ECONNRESET:
+			/* Simultaneous closes; not a problem. */
+			break;
+		default:
+			/*
+			 * Unexpected error; treat this as a broken connection
+			 * but don't die in case the error originates from some
+			 * sort of network issue rather than from an error in
+			 * spiped itself.
+			 */
+			goto fail;
 		}
 	}
 
@@ -182,6 +186,13 @@ eof:
 	/* Inform the upstream that our status has changed. */
 	return ((P->callback)(P->cookie));
 
+fail:
+	/* Record that this connection is broken. */
+	*(P->status) = -1;
+
+	/* Inform the upstream that our status has changed. */
+	return ((P->callback)(P->cookie));
+
 err0:
 	/* Failure! */
 	return (-1);
