@@ -1,3 +1,4 @@
+#include <assert.h>
 #include <signal.h>
 #include <stddef.h>
 #include <stdlib.h>
@@ -73,9 +74,9 @@ err0:
 
 /**
  * graceful_shutdown_initialize(callback, caller_cookie):
- * Initializes a signal handler for SIGTERM, and starts a continuous 1-second
- * timer which checks if SIGTERM was given; if detected, calls ${callback} and
- * gives it the ${caller_cookie}.
+ * Initialize a signal handler for SIGTERM, and start a continuous 1-second
+ * timer which checks if SIGTERM was given; if detected, call ${callback} and
+ * give it the ${caller_cookie}.
  */
 int
 graceful_shutdown_initialize(int (* begin_shutdown_parent)(void *),
@@ -111,3 +112,26 @@ err0:
 	/* Failure! */
 	return (-1);
 }
+
+/**
+ * graceful_shutdown_manual(void):
+ * Shutdown immediately, without needing a SIGTERM.
+ */
+void
+graceful_shutdown_manual(void)
+{
+
+	/* Sanity check: we must be initialized. */
+	assert(begin_shutdown != NULL);
+	assert(caller_cookie != NULL);
+
+	/* Stop the timer. */
+	if (timer_cookie != NULL) {
+		events_timer_cancel(timer_cookie);
+		timer_cookie = NULL;
+	}
+
+	/* Shut down. */
+	should_shutdown = 1;
+	graceful_shutdown(NULL);
+}
