@@ -1,31 +1,48 @@
 # Should be sourced by `command -p sh path/to/cpusupport.sh "$PATH"` from
 # within a Makefile.
-if ! [ ${PATH} = "$1" ]; then
-	echo "WARNING: POSIX violation: $SHELL's command -p resets \$PATH" 1>&2
+if ! [ "${PATH}" = "$1" ]; then
+	echo "WARNING: POSIX violation: ${SHELL}'s command -p resets \$PATH" 1>&2
 	PATH=$1
 fi
+
 # Standard output should be written to cpusupport-config.h, which is both a
 # C header file defining CPUSUPPORT_ARCH_FEATURE macros and sourceable sh
 # code which sets CFLAGS_ARCH_FEATURE environment variables.
 SRCDIR=$(command -p dirname "$0")
 
+CFLAGS_HARDCODED="-D_POSIX_C_SOURCE=200809L -D_XOPEN_SOURCE=700"
+
+# Do we want to record stderr to a file?
+if [ "${DEBUG:-0}" -eq "0" ]; then
+	outcc="/dev/null"
+else
+	outcc="cpusupport-stderr.log"
+	rm -f "${outcc}"
+fi
+
 feature() {
 	ARCH=$1
 	FEATURE=$2
 	shift 2;
-	if ! [ -f ${SRCDIR}/cpusupport-$ARCH-$FEATURE.c ]; then
+
+	# Bail if we didn't include this feature in this source tree.
+	feature_filename="${SRCDIR}/cpusupport-${ARCH}-${FEATURE}.c"
+	if ! [ -f "${feature_filename}" ]; then
 		return
 	fi
-	printf "Checking if compiler supports $ARCH $FEATURE feature..." 1>&2
+
+	# Check if we can compile this feature (and any required arguments).
+	printf "Checking if compiler supports %s %s feature..."		\
+	    "${ARCH}" "${FEATURE}" 1>&2
 	for CPU_CFLAGS in "$@"; do
-		if ${CC} ${CFLAGS} -D_POSIX_C_SOURCE=200809L ${CPU_CFLAGS} \
-		    ${SRCDIR}/cpusupport-$ARCH-$FEATURE.c 2>/dev/null; then
+		if ${CC} ${CPPFLAGS} ${CFLAGS} ${CFLAGS_HARDCODED}	\
+		    ${CPU_CFLAGS} "${feature_filename}" 2>>"${outcc}"; then
 			rm -f a.out
 			break;
 		fi
 		CPU_CFLAGS=NOTSUPPORTED;
 	done
-	case $CPU_CFLAGS in
+	case ${CPU_CFLAGS} in
 	NOTSUPPORTED)
 		echo " no" 1>&2
 		;;
@@ -34,7 +51,7 @@ feature() {
 		echo "#define CPUSUPPORT_${ARCH}_${FEATURE} 1"
 		;;
 	*)
-		echo " yes, via $CPU_CFLAGS" 1>&2
+		echo " yes, via ${CPU_CFLAGS}" 1>&2
 		echo "#define CPUSUPPORT_${ARCH}_${FEATURE} 1"
 		echo "#ifdef cpusupport_dummy"
 		echo "export CFLAGS_${ARCH}_${FEATURE}=\"${CPU_CFLAGS}\""
