@@ -1,9 +1,9 @@
-#ifndef _CRYPTO_DH_GROUP14_H_
-#define _CRYPTO_DH_GROUP14_H_
+#ifndef CRYPTO_DH_GROUP14_H_
+#define CRYPTO_DH_GROUP14_H_
 
 #include <stdint.h>
 
 /* Diffie-Hellman group #14, from RFC 3526. */
 extern const uint8_t crypto_dh_group14[];
 
-#endif /* !_CRYPTO_DH_GROUP14_H_ */
+#endif /* !CRYPTO_DH_GROUP14_H_ */
