@@ -1,5 +1,5 @@
-#ifndef _ELASTICARRAY_H_
-#define _ELASTICARRAY_H_
+#ifndef ELASTICARRAY_H_
+#define ELASTICARRAY_H_
 
 #include <stddef.h>
 
@@ -43,7 +43,7 @@ int elasticarray_resize(struct elasticarray *, size_t, size_t);
  * functions have been called with different values of reclen).  The value
  * ${reclen} must be positive.
  */
-size_t elasticarray_getsize(struct elasticarray *, size_t);
+size_t elasticarray_getsize(const struct elasticarray *, size_t);
 
 /**
  * elasticarray_append(EA, buf, nrec, reclen):
@@ -78,13 +78,6 @@ int elasticarray_truncate(struct elasticarray *);
  */
 void * elasticarray_get(struct elasticarray *, size_t, size_t);
 
-/**
- * elasticarray_iter(EA, reclen, fp):
- * Run the ${fp} function on every member of the array.  The value ${reclen}
- * must be positive.
- */
-void elasticarray_iter(struct elasticarray *, size_t, void(*)(void *));
-
 /**
  * elasticarray_free(EA):
  * Free the elastic array ${EA}.  Takes O(1) time.
@@ -106,19 +99,20 @@ int elasticarray_export(struct elasticarray *, void **, size_t *, size_t);
  * that the elastic array remains intact.)  The value ${reclen} must be
  * positive.
  */
-int elasticarray_exportdup(struct elasticarray *, void **, size_t *, size_t);
+int elasticarray_exportdup(const struct elasticarray *, void **, size_t *,
+    size_t);
 
 /**
  * ELASTICARRAY_DECL(type, prefix, rectype):
  * Declare the type ${type} and the following functions:
  * ${type} ${prefix}_init(size_t nrec);
  * int ${prefix}_resize(${type} EA, size_t nrec);
- * size_t ${prefix}_getsize(${type} EA);
+ * size_t ${prefix}_getsize(const ${type} EA);
  * int ${prefix}_append(${type} EA, const void * buf, size_t nrec);
  * void ${prefix}_shrink(${type} EA, size_t nrec);
  * int ${prefix}_truncate(${type} EA);
  * ${rectype} * ${prefix}_get(${type} EA, size_t pos);
- * void ${prefix}_iter(${type} EA, void(*)(void *));
+ * void ${prefix}_iter(${type} EA, void (*)(void *));
  * void ${prefix}_free(${type} EA);
  */
 #define ELASTICARRAY_DECL(type, prefix, rectype)			\
@@ -137,9 +131,10 @@ int elasticarray_exportdup(struct elasticarray *, void **, size_t *, size_t);
 		    nrec, sizeof(rectype)));				\
 	}								\
 	static inline size_t						\
-	prefix##_getsize(struct prefix##_struct * EA)			\
+	prefix##_getsize(const struct prefix##_struct * EA)		\
 	{								\
-		return (elasticarray_getsize((struct elasticarray *)EA,	\
+		return (elasticarray_getsize(				\
+		    (const struct elasticarray *)EA,			\
 		    sizeof(rectype)));					\
 	}								\
 	static inline int						\
@@ -172,10 +167,12 @@ int elasticarray_exportdup(struct elasticarray *, void **, size_t *, size_t);
 	}								\
 	static inline void						\
 	prefix##_iter(struct prefix##_struct * EA,			\
-	    void(* free_fp)(rectype *))					\
+	    void (* fp)(rectype *))					\
 	{								\
-		elasticarray_iter((struct elasticarray *)EA,		\
-		    sizeof(rectype), (void (*)(void *))free_fp);	\
+		size_t i;						\
+									\
+		for (i = 0; i < prefix##_getsize(EA); i++)		\
+			fp(prefix##_get(EA, i));			\
 	}								\
 	static inline void						\
 	prefix##_free(struct prefix##_struct * EA)			\
@@ -190,11 +187,11 @@ int elasticarray_exportdup(struct elasticarray *, void **, size_t *, size_t);
 		    (void **)buf, nrec, sizeof(rectype)));		\
 	}								\
 	static inline int						\
-	prefix##_exportdup(struct prefix##_struct * EA, rectype ** buf,	\
-	    size_t * nrec)						\
+	prefix##_exportdup(const struct prefix##_struct * EA,		\
+	    rectype ** buf, size_t * nrec)				\
 	{								\
-		return (						\
-		    elasticarray_exportdup((struct elasticarray *)EA,	\
+		return (elasticarray_exportdup(				\
+		    (const struct elasticarray *)EA,			\
 		    (void **)buf, nrec, sizeof(rectype)));		\
 	}								\
 	static void (* prefix##_dummyptr)(void);			\
@@ -218,4 +215,4 @@ int elasticarray_exportdup(struct elasticarray *, void **, size_t *, size_t);
 	static void (* prefix##_dummyptr)(void) = prefix##_dummy;	\
 	typedef struct prefix##_struct * type
 
-#endif /* !_ELASTICARRAY_H_ */
+#endif /* !ELASTICARRAY_H_ */
