@@ -1,10 +1,13 @@
-#ifndef _MPOOL_H_
-#define _MPOOL_H_
+#ifndef MPOOL_H_
+#define MPOOL_H_
 
+#include <assert.h>
 #include <stdint.h>
 #include <stdlib.h>
 #include <string.h>
 
+#include "ctassert.h"
+
 /**
  * Memory allocator cache.  Memory allocations can be returned to the pool
  * and reused by a subsequent allocation without returning all the way to
@@ -23,15 +26,18 @@ struct mpool {
 	uint64_t nempties;
 	int state;
 	void ** allocs_static;
-	void (*atexitfunc)(void);
+	void (* atexitfunc)(void);
 };
 
 static inline void
 mpool_atexit(struct mpool * M)
 {
 
+	/* Free all items on the stack. */
 	while (M->stacklen)
 		free(M->allocs[--M->stacklen]);
+
+	/* If we allocated a stack, free it. */
 	if (M->allocs != M->allocs_static)
 		free(M->allocs);
 }
@@ -40,14 +46,23 @@ static inline void *
 mpool_malloc(struct mpool * M, size_t len)
 {
 
+	/* Count the total number of allocation requests. */
 	M->nallocs++;
+
+	/* If we have an object on the stack, use that. */
 	if (M->stacklen)
 		return (M->allocs[--(M->stacklen)]);
+
+	/* Count allocation requests where the pool was already empty. */
 	M->nempties++;
+
+	/* Initialize the atexit function (the first time we reach here). */
 	if (M->state == 0) {
 		atexit(M->atexitfunc);
 		M->state = 1;
 	}
+
+	/* Allocate a new object. */
 	return (malloc(len));
 }
 
@@ -56,15 +71,25 @@ mpool_free(struct mpool * M, void * p)
 {
 	void ** allocs_new;
 
+	/* Behave consistently with free(NULL). */
 	if (p == NULL)
 		return;
 
+	/* If we have space in the stack, cache the object. */
 	if (M->stacklen < M->allocsize) {
 		M->allocs[M->stacklen++] = p;
 		return;
 	}
 
-	if (M->nempties	> (M->nallocs >> 8)) {
+	/*
+	 * Autotuning: If more than 1/256 of mpool_malloc() calls resulted in
+	 * a malloc(), double the stack.
+	 */
+	if (M->nempties > (M->nallocs >> 8)) {
+		/* Sanity check. */
+		assert(M->allocsize > 0);
+
+		/* Allocate new stack and copy pointers into it. */
 		allocs_new = (void **)malloc(M->allocsize * 2 * sizeof(void *));
 		if (allocs_new) {
 			memcpy(allocs_new, M->allocs,
@@ -78,6 +103,8 @@ mpool_free(struct mpool * M, void * p)
 			free(p);
 	} else
 		free(p);
+
+	/* Reset statistics. */
 	M->nempties = 0;
 	M->nallocs = 0;
 }
@@ -104,6 +131,8 @@ static struct mpool mpool_##name##_rec =			\
     {0, size, mpool_##name##_static, 0, 0, 0,			\
     mpool_##name##_static, mpool_##name##_atexit};		\
 								\
+CTASSERT(size > 0);						\
+								\
 static void							\
 mpool_##name##_atexit(void)					\
 {								\
@@ -125,6 +154,16 @@ mpool_##name##_free(type * p)					\
 	mpool_free(&mpool_##name##_rec, p);			\
 }								\
 								\
+static void (* mpool_##name##_dummyptr)(void);			\
+static inline void						\
+mpool_##name##_dummyfunc(void)					\
+{								\
+								\
+	(void)mpool_##name##_malloc;				\
+	(void)mpool_##name##_free;				\
+	(void)mpool_##name##_dummyptr;				\
+}								\
+static void (* mpool_##name##_dummyptr)(void) = mpool_##name##_dummyfunc; \
 struct mpool_##name##_dummy
 
-#endif /* !_MPOOL_H_ */
+#endif /* !MPOOL_H_ */
