@@ -11,7 +11,7 @@
 
 /* Event structure. */
 struct eventrec {
-	int (*func)(void *);
+	int (* func)(void *);
 	void * cookie;
 };
 
@@ -28,7 +28,7 @@ static volatile sig_atomic_t interrupt_requested = 0;
  * Package ${func}, ${cookie} into a struct eventrec.
  */
 struct eventrec *
-events_mkrec(int (*func)(void *), void * cookie)
+events_mkrec(int (* func)(void *), void * cookie)
 {
 	struct eventrec * r;
 
@@ -89,7 +89,7 @@ doevent(struct eventrec * r)
  * more runnable events.
  */
 static int
-_events_run(void)
+events_run_internal(void)
 {
 	struct eventrec * r;
 	struct timeval * tv;
@@ -190,7 +190,7 @@ events_run(void)
 	int rc;
 
 	/* Call the real function. */
-	rc = _events_run();
+	rc = events_run_internal();
 
 	/* Reset interrupt_requested after quitting the loop. */
 	interrupt_requested = 0;
@@ -207,14 +207,14 @@ events_run(void)
  * (and return 0).
  */
 int
-events_spin(int * done)
+events_spin(const int * done)
 {
 	int rc = 0;
 
 	/* Loop until we're done or have a non-zero status. */
 	while ((done[0] == 0) && (rc == 0) && (interrupt_requested == 0)) {
 		/* Run events. */
-		rc = _events_run();
+		rc = events_run_internal();
 	}
 
 	/* Reset interrupt_requested after quitting the loop. */
