@@ -1,5 +1,5 @@
-#ifndef _SOCK_UTIL_H_
-#define _SOCK_UTIL_H_
+#ifndef SOCK_UTIL_H_
+#define SOCK_UTIL_H_
 
 #include <stddef.h>
 #include <stdint.h>
@@ -49,4 +49,19 @@ struct sock_addr * sock_addr_deserialize(const uint8_t *, size_t);
  */
 char * sock_addr_prettyprint(const struct sock_addr *);
 
-#endif /* !_SOCK_UTIL_H_ */
+/**
+ * sock_addr_ensure_port(addr):
+ * Allocate a new string to serve as the address for sock_resolve().
+ * If ${addr} contains a port number or is the address of a Unix domain
+ * socket, duplicate that string; if not, add a port number of ":0".
+ */
+char * sock_addr_ensure_port(const char *);
+
+/**
+ * sock_addr_validate(addr):
+ * Check that ${addr} is syntactically valid, but do not perform any address
+ * resolution.
+ */
+int sock_addr_validate(const char *);
+
+#endif /* !SOCK_UTIL_H_ */
