@@ -2,7 +2,6 @@
 
 #include <fcntl.h>
 #include <limits.h>
-#include <stdio.h>
 #include <stdlib.h>
 #include <unistd.h>
 
@@ -15,10 +14,10 @@ main(int argc, char ** argv)
 {
 	/* Command-line parameters. */
 	const char * addr = NULL;
-	ssize_t buflen;
+	size_t buflen;
 
 	/* Working variables. */
-	struct sock_addr ** sas;
+	struct sock_addr * sa;
 	int socket;
 	int socket_recv;
 	char * buffer;
@@ -38,19 +37,19 @@ main(int argc, char ** argv)
 	}
 
 	/* Allocate buffer. */
-	if ((buffer = malloc((size_t)buflen)) == NULL) {
+	if ((buffer = malloc(buflen)) == NULL) {
 		warnp("malloc");
 		goto err0;
 	}
 
 	/* Resolve the address. */
-	if ((sas = sock_resolve(addr)) == NULL) {
-		warn0("sock_resolve");
+	if ((sa = sock_resolve_one(addr, 0)) == NULL) {
+		warn0("sock_resolve_one");
 		goto err1;
 	}
 
 	/* Create a socket, bind it, mark it as listening. */
-	if ((socket = sock_listener(sas[0])) == -1) {
+	if ((socket = sock_listener(sa)) == -1) {
 		warn0("sock_listener");
 		goto err2;
 	}
@@ -70,9 +69,9 @@ main(int argc, char ** argv)
 
 	/* Receive data, but do nothing with it. */
 	do {
-		r = recv(socket_recv, buffer, (size_t)buflen, MSG_WAITALL);
-	} while (r == buflen);
-	if (r != 0) {
+		r = recv(socket_recv, buffer, buflen, MSG_WAITALL);
+	} while (r == (ssize_t)buflen);
+	if (r == -1) {
 		warnp("recv");
 		goto err4;
 	}
@@ -88,18 +87,20 @@ main(int argc, char ** argv)
 		warnp("close");
 		goto err2;
 	}
-	sock_addr_freelist(sas);
+	sock_addr_free(sa);
 	free(buffer);
 
 	/* Success! */
 	exit(0);
 
 err4:
-	close(socket_recv);
+	if (close(socket_recv))
+		warnp("close");
 err3:
-	close(socket);
+	if (close(socket))
+		warnp("close");
 err2:
-	sock_addr_freelist(sas);
+	sock_addr_free(sa);
 err1:
 	free(buffer);
 err0:
