@@ -5,6 +5,7 @@
 #include "dnsthread.h"
 #include "events.h"
 #include "network.h"
+#include "queue.h"
 #include "sock.h"
 #include "sock_util.h"
 #include "warnp.h"
@@ -17,6 +18,7 @@ struct accept_state {
 	int s;
 	const char * tgt;
 	struct sock_addr ** sas;
+	const struct sock_addr * sa_b;
 	double rtime;
 	int decr;
 	int nopfs;
@@ -30,15 +32,14 @@ struct accept_state {
 	double timeo;
 	void * accept_cookie;
 	void * dnstimer_cookie;
-	struct conn_list_node * conn_cookies;
+	LIST_HEAD(conn_head, conn_list_node) conn_cookies;
 	DNSTHREAD T;
 };
 
 /* Doubly linked list. */
 struct conn_list_node {
 	void * conn_cookie;
-	struct conn_list_node * prev;
-	struct conn_list_node * next;
+	LIST_ENTRY(conn_list_node) entries;
 	struct accept_state * A;
 };
 
@@ -120,24 +121,13 @@ callback_conndied(void * cookie, int reason)
 	(void)reason; /* UNUSED */
 
 	/* We should always have a non-empty list of conn_cookies. */
-	assert(A->conn_cookies != NULL);
+	assert(!LIST_EMPTY(&A->conn_cookies));
 
 	/* We've lost a connection. */
 	A->nconn -= 1;
 
 	/* Remove the closed connection from the list of conn_cookies. */
-	if (node_ptr == A->conn_cookies) {
-		/* Closed conn_cookie is first in the list. */
-		A->conn_cookies = node_ptr->next;
-		if (node_ptr->next != NULL)
-			node_ptr->next->prev = NULL;
-	} else {
-		/* Closed conn_cookie is in the middle of list. */
-		assert(node_ptr->prev != NULL);
-		node_ptr->prev->next = node_ptr->next;
-		if (node_ptr->next != NULL)
-			node_ptr->next->prev = node_ptr->prev;
-	}
+	LIST_REMOVE(node_ptr, entries);
 
 	/* Clean up the now-unused node. */
 	free(node_ptr);
@@ -177,26 +167,18 @@ callback_gotconn(void * cookie, int s)
 	/* Create new conn_list_node. */
 	if ((node_new = malloc(sizeof(struct conn_list_node))) == NULL)
 		goto err2;
-	node_new->prev = NULL;
-	node_new->next = NULL;
 	node_new->A = A;
 
 	/* Create a new connection. */
-	if ((node_new->conn_cookie = proto_conn_create(s, sas, A->decr,
-	    A->nopfs, A->requirepfs, A->nokeepalive, A->K, A->timeo,
-	    callback_conndied, node_new)) == NULL) {
+	if ((node_new->conn_cookie = proto_conn_create(s, sas, A->sa_b,
+	    A->decr, A->nopfs, A->requirepfs, A->nokeepalive, A->K,
+	    A->timeo, callback_conndied, node_new)) == NULL) {
 		warnp("Failure setting up new connection");
 		goto err3;
 	}
 
-	/* Link node_new to the beginning of the conn_cookies list. */
-	if (A->conn_cookies != NULL) {
-		node_new->next = A->conn_cookies;
-		node_new->next->prev = node_new;
-	}
-
 	/* Insert node_new to the beginning of the conn_cookies list. */
-	A->conn_cookies = node_new;
+	LIST_INSERT_HEAD(&A->conn_cookies, node_new, entries);
 
 	/* Accept another connection if we can. */
 	if (doaccept(A))
@@ -211,19 +193,21 @@ err2:
 	sock_addr_freelist(sas);
 err1:
 	A->nconn -= 1;
-	close(s);
+	if (close(s))
+		warnp("close");
 err0:
 	/* Failure! */
 	return (-1);
 }
 
 /**
- * dispatch_accept(s, tgt, rtime, sas, decr, nopfs, requirepfs, nokeepalive, K,
- *     nconn_max, timeo, conndone):
- * Start accepting connections on the socket ${s}.  Connect to the target
- * ${tgt}, re-resolving it every ${rtime} seconds if ${rtime} > 0; on address
- * resolution failure use the most recent successfully obtained addresses, or
- * the addresses ${sas}.  If ${decr} is 0, encrypt the outgoing connections; if
+ * dispatch_accept(s, tgt, rtime, sas, sa_b, decr, nopfs, requirepfs,
+ *     nokeepalive, K, nconn_max, timeo, conndone):
+ * Start accepting connections on the socket ${s}.  Bind outgoing address to
+ * ${sa_b} if it is not NULL.  Connect to the target ${tgt}, re-resolving
+ * it every ${rtime} seconds if ${rtime} > 0; on address resolution
+ * failure use the most recent successfully obtained addresses, or the
+ * addresses ${sas}.  If ${decr} is 0, encrypt the outgoing connections; if
  * ${decr} is non-zero, decrypt the incoming connections.  Don't accept more
  * than ${nconn_max} connections.  If ${nopfs} is non-zero, don't use perfect
  * forward secrecy.  If ${requirepfs} is non-zero, require that both ends use
@@ -236,9 +220,9 @@ err0:
  */
 void *
 dispatch_accept(int s, const char * tgt, double rtime, struct sock_addr ** sas,
-    int decr, int nopfs, int requirepfs, int nokeepalive,
-    const struct proto_secret * K, size_t nconn_max, double timeo,
-    int * conndone)
+    const struct sock_addr * sa_b, int decr, int nopfs, int requirepfs,
+    int nokeepalive, const struct proto_secret * K, size_t nconn_max,
+    double timeo, int * conndone)
 {
 	struct accept_state * A;
 
@@ -248,6 +232,7 @@ dispatch_accept(int s, const char * tgt, double rtime, struct sock_addr ** sas,
 	A->s = s;
 	A->tgt = tgt;
 	A->sas = sas;
+	A->sa_b = sa_b;
 	A->rtime = rtime;
 	A->decr = decr;
 	A->nopfs = nopfs;
@@ -262,7 +247,7 @@ dispatch_accept(int s, const char * tgt, double rtime, struct sock_addr ** sas,
 	A->T = NULL;
 	A->accept_cookie = NULL;
 	A->dnstimer_cookie = NULL;
-	A->conn_cookies = NULL;
+	LIST_INIT(&A->conn_cookies);
 
 	/* If address re-resolution is enabled... */
 	if (rtime > 0.0) {
@@ -304,15 +289,22 @@ void
 dispatch_shutdown(void * dispatch_cookie)
 {
 	struct accept_state * A = dispatch_cookie;
+	struct conn_list_node * C;
 
 	/*
 	 * Shutdown any open connections.  proto_conn_drop() will call
 	 * callback_conndied(), which removes the relevant conn_list_node from
 	 * the list of conn_cookies.
 	 */
-	while (A->conn_cookies != NULL)
-		proto_conn_drop(A->conn_cookies->conn_cookie,
-		    PROTO_CONN_CANCELLED);
+	while ((C = LIST_FIRST(&A->conn_cookies)) != NULL) {
+		proto_conn_drop(C->conn_cookie, PROTO_CONN_CANCELLED);
+
+		/*
+		 * Convince static analyzers that C->conn_cookie is no longer
+		 * in the list.
+		 */
+		assert(C != LIST_FIRST(&A->conn_cookies));
+	}
 
 	if (A->accept_cookie != NULL)
 		network_accept_cancel(A->accept_cookie);
@@ -321,7 +313,8 @@ dispatch_shutdown(void * dispatch_cookie)
 	if (A->T != NULL)
 		dnsthread_kill(A->T);
 	sock_addr_freelist(A->sas);
-	close(A->s);
+	if (close(A->s))
+		warnp("close");
 	free(A);
 }
 
