@@ -18,26 +18,26 @@ scenario_cmd() {
 	setup_spiped_encryption_server
 
 	# Open and close a connection, keeping it open for 2 seconds.
-	setup_check_variables "multi open 2 seconds close"
+	setup_check "multi open 2 seconds close"
 	(
 		( echo "" ; sleep 2 ) |		\
-			 ${nc_client_binary} ${src_sock}
-		echo $? > ${c_exitfile}
+			 ${nc_client_binary} "${src_sock}"
+		echo $? > "${c_exitfile}"
 		touch "${flag_1}"
 	) &
 
 	# Open another connection (before the first has closed).
 	# Don't check that we've already finished the previous test.
-	setup_check_variables "multi open close" 0
+	setup_check "multi open close" 0
 	(
-		echo "" | ${nc_client_binary} ${src_sock}
-		echo $? > ${c_exitfile}
+		echo "" | ${nc_client_binary} "${src_sock}"
+		echo $? > "${c_exitfile}"
 		touch "${flag_2}"
 	) &
 
 	# Wait for both connections to have closed.
-	wait_for_file "${flag_1}"
-	wait_for_file "${flag_2}"
+	wait_while 0 test ! -e "${flag_1}"
+	wait_while 0 test ! -e "${flag_2}"
 
 	# Wait for server(s) to quit.
 	servers_stop
