@@ -28,10 +28,10 @@ scenario_cmd() {
 
 	for addr in ${addrs}
 	do
-		setup_check_variables "dnsthread-resolve ${addr}"
+		setup_check "dnsthread-resolve ${addr}"
 		${c_valgrind_cmd}				\
-		${dnsthread_resolve} ${addr} >> ${addr_output}
-		echo $? > ${c_exitfile}
+		"${dnsthread_resolve}" "${addr}" >> "${addr_output}"
+		echo $? > "${c_exitfile}"
 	done
 
 	# Wait for server(s) to quit.
