@@ -7,7 +7,7 @@ cmd="${scriptdir}/pthread_create_blocking_np/test_pthread_create_blocking_np"
 ### Actual command
 scenario_cmd() {
 	# Copy a file
-	setup_check_variables "test_pthread_create_blocking_np"
-	${c_valgrind_cmd} ${cmd}
-	echo $? > ${c_exitfile}
+	setup_check "test_pthread_create_blocking_np"
+	${c_valgrind_cmd} "${cmd}"
+	echo $? > "${c_exitfile}"
 }
