@@ -7,10 +7,10 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <time.h>
 #include <unistd.h>
 
 #include "getopt.h"
+#include "millisleep.h"
 #include "noeintr.h"
 #include "parsenum.h"
 #include "warnp.h"
@@ -48,16 +48,20 @@ basic_copy(const char * filename_in, const char * filename_out)
 	}
 
 	/* Clean up. */
-	close(out);
-	close(in);
+	if (close(out))
+		warnp("close");
+	if (close(in))
+		warnp("close");
 
 	/* Success! */
 	return (0);
 
 err2:
-	close(out);
+	if (close(out))
+		warnp("close");
 err1:
-	close(in);
+	if (close(in))
+		warnp("close");
 err0:
 	/* Failure! */
 	return (-1);
@@ -112,21 +116,6 @@ err0:
 	return (-1);
 }
 
-/* Wait duration can be interrupted by signals. */
-static int
-wait_ms(size_t msec)
-{
-	struct timespec ts;
-
-	/* Try to wait for the desired duration. */
-	ts.tv_sec = msec / 1000;
-	ts.tv_nsec = (msec % 1000) * 1000000;
-	nanosleep(&ts, NULL);
-
-	/* Success! */
-	return (0);
-}
-
 static int
 chain_one(void)
 {
@@ -162,7 +151,7 @@ chain_one(void)
 	}
 
 	/* Wait for thread to start. */
-	wait_ms(100);
+	millisleep(100);
 
 	/*
 	 * Send the message; this will not block because the message is
@@ -188,7 +177,7 @@ chain_one(void)
 		warn0("Message is not the expected length");
 		goto err2;
 	}
-	if (strncmp(buf, msg, msglen) != 0) {
+	if (memcmp(buf, msg, msglen) != 0) {
 		warn0("failed to get the (full?) message");
 		goto err2;
 	}
@@ -274,7 +263,7 @@ chain_two(void)
 	}
 
 	/* Wait for thread to start. */
-	wait_ms(100);
+	millisleep(100);
 
 	/*
 	 * Send the message; this will not block because the message is
@@ -306,7 +295,7 @@ chain_two(void)
 		warn0("Message is not the expected length");
 		goto err2;
 	}
-	if (strncmp(buf, msg, msglen) != 0) {
+	if (memcmp(buf, msg, msglen) != 0) {
 		warn0("failed to get the (full?) message");
 		goto err2;
 	}
@@ -462,7 +451,7 @@ main(int argc, char ** argv)
 	}
 
 	/* Run the desired test. */
-	switch(desired_test) {
+	switch (desired_test) {
 	case 1:
 		if ((filename_in == NULL) || (filename_out == NULL))
 			usage();
